@@ -1,6 +1,7 @@
 (ql:quickload :abcl-prove)
 
 (asdf:load-system :abcl-prove)
-(asdf:test-system :abcl-prove/t)
+(time 
+ (asdf:test-system :abcl-prove/t))
 
 ;;; also works as :abcl/t under some definitions
